@@ -104,35 +104,27 @@ impl Server {
                                     Route::Alias(q) => {
                                         let (response_body, mime_type) =
                                             resload.load(q[1..].to_string());
-                                        let header = vec![
+                                        let mut header = vec![
                                             HTTPResponseHeaders::ContentType(mime_type),
                                             HTTPResponseHeaders::Server(
                                                 RSWEB_SERVER_STR.to_string(),
                                             ),
                                         ];
-                                        let mut response = HTTPResponse::new(
-                                            StatusCode::Ok,
-                                            header,
-                                            Body::new(response_body.clone()),
-                                        );
+                                        let mut status = StatusCode::Ok;
+                                        let mut body = Body::new(response_body.clone());
                                         if response_body.is_empty() {
-                                            response = HTTPResponse::new(
-                                                StatusCode::NotFound,
-                                                vec![
-                                                    HTTPResponseHeaders::ContentType(
-                                                        MimeType::Html,
-                                                    ),
-                                                    HTTPResponseHeaders::Server(
-                                                        RSWEB_SERVER_STR.to_string(),
-                                                    ),
-                                                ],
-                                                Body::new(String::from("<h1>404 not found</h1>")),
-                                            );
+                                            status = StatusCode::NotFound;
+                                            body = Body::new(String::from("<h1>404 not found</h1>"));
+                                            header = vec![HTTPResponseHeaders::ContentType(MimeType::Html), HTTPResponseHeaders::Server(RSWEB_SERVER_STR.to_string())];
                                         }
-                                        response
+                                        header.push(HTTPResponseHeaders::ContentLength(body.get_bytes().len()));
+                                        if req.get_method() == HTTPMethod::Head {
+                                            body = Body::new(String::new());
+                                        }
+                                        HTTPResponse::new(status, header, body)
                                     }
                                 };
-                                match stream.write(resp.to_string().as_str().as_bytes()) {
+                                match stream.write(&resp.to_bytes()) {
                                     Ok(_) => (),
                                     Err(_) => logging
                                         .log("failed to write to stream", log::LogType::Error),
@@ -146,27 +138,27 @@ impl Server {
                             } else {
                                 let (response_body, mime_type) =
                                     resload.load(req.get_path()[1..].to_string());
-                                let header = vec![
+                                let mut header = vec![
                                     HTTPResponseHeaders::ContentType(mime_type),
                                     HTTPResponseHeaders::Server(RSWEB_SERVER_STR.to_string()),
                                 ];
-                                let mut response = HTTPResponse::new(
-                                    StatusCode::Ok,
-                                    header,
-                                    Body::new(response_body.clone()),
-                                );
+                                let mut status = StatusCode::Ok;
+                                let mut body = Body::new(response_body.clone());
                                 if response_body.is_empty() {
-                                    let header = vec![
+                                    header = vec![
                                         HTTPResponseHeaders::ContentType(MimeType::Html),
                                         HTTPResponseHeaders::Server(RSWEB_SERVER_STR.to_string()),
                                     ];
-                                    response = HTTPResponse::new(
-                                        StatusCode::NotFound,
-                                        header,
-                                        Body::new(String::from("<h1>404 not found</h1>")),
-                                    );
+                                    status = StatusCode::NotFound;
+                                    body = Body::new(String::from("<h1>404 not found</h1>"));
                                 }
-                                match stream.write(response.to_string().as_str().as_bytes()) {
+                                header.push(HTTPResponseHeaders::ContentLength(body.get_bytes().len()));
+                                if req.get_method() == HTTPMethod::Head {
+                                    body = Body::new(String::new());
+                                }
+
+                                let response = HTTPResponse::new(status, header, body);
+                                match stream.write(&response.to_bytes()) {
                                     Ok(_) => (),
                                     Err(_) => logging
                                         .log("failed to write to stream", log::LogType::Error),
